@@ -135,6 +135,10 @@ class StateModificationCommand(QUndoCommand):
         self.__stateBefore = before
         self.__stateAfter = after
 
+    def isFoldCommand(self):
+        '''Check if command change fold attribute'''
+        return 'folded' in self.__stateAfter.keys()
+
     def undo(self):
         '''Change node attributes to it original state'''
         self.__node.setAttributes(**self.__stateBefore)
@@ -144,13 +148,13 @@ class StateModificationCommand(QUndoCommand):
         self.__node.setAttributes(**self.__stateAfter)
 
 
-class HivemindCommand(object):
+class SimpleCommand(object):
     '''Base class for commands that are not stored in undo stack'''
     pass
 
 
-class ActionCommand(HivemindCommand):
-    '''Class for storing various commands'''
+class ActionCommand(SimpleCommand):
+    '''Stores various commands'''
 
     readable('action')
 
@@ -159,12 +163,12 @@ class ActionCommand(HivemindCommand):
         @param action: Action to be executed
         @type action: str
         '''
-        HivemindCommand.__init__(self)
+        SimpleCommand.__init__(self)
         self.__action = action
 
 
-class CurrentNodeCommand(HivemindCommand):
-    '''Command to change current mind map node'''
+class CurrentNodeCommand(SimpleCommand):
+    '''Stores current node'''
 
     readable('node')
 
@@ -173,5 +177,5 @@ class CurrentNodeCommand(HivemindCommand):
         @param node: Current node
         @type node: Node
         '''
-        HivemindCommand.__init__(self)
+        SimpleCommand.__init__(self)
         self.__node = node
