@@ -26,12 +26,12 @@ Dialogs for Desktop platform
 
 from PyQt4.QtGui import QToolBar, QIcon, QTabWidget, QGridLayout, \
 QHBoxLayout, QPalette, QTextBrowser, QFrame, QLabel, QDialogButtonBox, \
-QVBoxLayout, QGroupBox, QWidget, QPushButton, QKeySequence, QScrollArea
-from PyQt4.QtCore import SIGNAL, QSize, Qt, QObject
+QVBoxLayout, QGroupBox, QWidget, QPushButton, QKeySequence
+from PyQt4.QtCore import QSize, Qt
 from hivemind.dialogs import EditNodeDialog, EditLabelDialog, IconDialog, \
 AboutDialog, EditEdgeDialog, SettingsDialog, NetworkConnectionDialog, \
 AffiliationDialog, NetworkSettingsDialog, NetworkClientDialog
-from hivemind.gui_widgets import SettingsCreator, FindToolBar
+from hivemind.gui_widgets import FindToolBar
 from hivemind.attribute import adaptCallable
 import hivemind.__version__ as __version__
 
@@ -67,10 +67,8 @@ class DesktopEditNodeDialog(EditNodeDialog):
         lastLineLayout.addWidget(self._buttonBox)
         mainLayout.addLayout(lastLineLayout)
         QWidget.setTabOrder(self._editor, self.__tabWidget)
-        QObject.connect(self._textHtmlAction, SIGNAL('toggled(bool)'),
-                adaptCallable(self._enableSourceTab))
-        QObject.connect(self.__tabWidget, SIGNAL('currentChanged(int)'),
-                adaptCallable(self._changedMode))
+        self._textHtmlAction.toggled.connect(adaptCallable(self._enableSourceTab))
+        self.__tabWidget.currentChanged.connect(adaptCallable(self._changedMode))
         self.setLayout(mainLayout)
         self._editor.setFocus()
 
@@ -147,36 +145,13 @@ class DesktopEditLabelDialog(EditLabelDialog):
     def _initComponents(self):
         '''Form initialization'''
         #create toolbar
-        toolbar = QToolBar(self)
         self._boldAction.setToolTip(self.tr('Bold'))
         self._boldAction.setIcon(QIcon.fromTheme('format-text-bold'))
-        toolbar.addAction(self._boldAction)
         self._italicAction.setToolTip(self.tr('Italic'))
         self._italicAction.setIcon(QIcon.fromTheme('format-text-italic'))
-        toolbar.addAction(self._italicAction)
         self._underlineAction.setToolTip(self.tr('Underline'))
         self._underlineAction.setIcon(QIcon.fromTheme('format-text-underline'))
-        toolbar.addAction(self._underlineAction)
-        secondaryLayout = QHBoxLayout()
-        secondaryLayout.addWidget(self._parentFont)
-        secondaryLayout.addSpacing(20)
-        secondaryLayout.addWidget(self._parentColor)
-        secondaryLayout.addWidget(self._colorButton)
-        mainLayout = QGridLayout()
-        mainLayout.addWidget(toolbar, 0, 0, 1, 2)
-        mainLayout.addWidget(self._comboFont, 0, 2, 1, 5)
-        mainLayout.addWidget(self._comboSize, 0, 7, 1, 3)
-        mainLayout.addWidget(self._editor, 1, 0, 1, 10)
-        mainLayout.addLayout(secondaryLayout, 2, 0, 1, 10)
-        bottomLayout = QHBoxLayout()
-        bottomLayout.addWidget(self._propagateFormatting)
-        bottomLayout.addStretch()
-        bottomLayout.addWidget(self._buttonBox)
-        mainLayout.addLayout(bottomLayout, 3, 0, 1, 10)
-        self.setLayout(mainLayout)
-        QWidget.setTabOrder(self._editor, self._buttonBox)
-        QWidget.setTabOrder(self._buttonBox, self._comboFont)
-        QWidget.setTabOrder(self._comboFont, self._comboSize)
+        self._layoutComponents(self._editor)
 
 
 class DesktopIconDialog(IconDialog):
@@ -228,13 +203,10 @@ class DesktopAboutDialog(AboutDialog):
     '''
     def __init__(self, parent = None):
         AboutDialog.__init__(self, parent)
-        self._createComponents()
-        self._initComponents()
 
     def _createComponents(self):
         '''Create components'''
         #pylint: disable = W0201
-        AboutDialog._createComponents(self)
         self._logo.setPixmap(self._logoImage.scaled(QSize(72, 72)))
         palette = self.palette()
         palette.setColor(QPalette.Base, self.palette().color(QPalette.Window))
@@ -288,7 +260,7 @@ class DesktopAboutDialog(AboutDialog):
         mainLayout.addWidget(self._tabWidget)
         mainLayout.addWidget(close)
         self.setLayout(mainLayout)
-        QObject.connect(close, SIGNAL('rejected()'), self.close)
+        close.rejected.connect(self.close)
 
     @classmethod
     def _generateInfo(cls, info, name):
@@ -315,22 +287,6 @@ class DesktopEditEdgeDialog(EditEdgeDialog):
         EditEdgeDialog.__init__(self, node, parent)
         self._initComponents()
 
-    def _initComponents(self):
-        '''Form initialization'''
-        colorLayout = QHBoxLayout()
-        colorLayout.addWidget(self._parentColor)
-        colorLayout.addWidget(self._colorLabel)
-        colorLayout.addWidget(self._colorButton)
-        mainLayout = QGridLayout()
-        mainLayout.addWidget(self._widthLabel, 0, 0)
-        mainLayout.addWidget(self._styleLabel, 0, 1)
-        mainLayout.addWidget(self._edgeWidthComboBox, 1, 0)
-        mainLayout.addWidget(self._edgeStyleComboBox, 1, 1)
-        mainLayout.addWidget(self._nodeStyleLabel, 2, 0, 1, 2)
-        mainLayout.addWidget(self._nodeStyleComboBox, 3, 0, 1, 2)
-        mainLayout.addLayout(colorLayout, 4, 0, 1, 2)
-        mainLayout.addWidget(self._buttonBox, 5, 0, 1, 2)
-        self.setLayout(mainLayout)
 
 class DesktopSettingsDialog(SettingsDialog):
     '''
@@ -342,49 +298,14 @@ class DesktopSettingsDialog(SettingsDialog):
         @type parent: QWidget
         '''
         SettingsDialog.__init__(self, parent)
-        self._general = SettingsCreator(['locale', 'confirmDelete', 'defaultZoomLevel',
+        self._createTab(self.tr('General'), ['locale', 'confirmDelete', 'defaultZoomLevel',
                 'maxNodeTextWidth'])
-        generalTab = QWidget()
-        generalTab.setLayout(self._general.getLayout())
-        self._node = SettingsCreator(['defaultFont', 'defaultNodeTextColor',
+        self._createTab(self.tr('Node'), ['defaultFont', 'defaultNodeTextColor',
                 'defaultNodeBackgroundColor', 'defaultSelectedNodeBackgroundColor'])
-        nodeTab = QWidget()
-        nodeTab.setLayout(self._node.getLayout())
-        self._edge = SettingsCreator(['defaultLabelFont', 'defaultLabelColor',
+        self._createTab(self.tr('Edge && label'), ['defaultLabelFont', 'defaultLabelColor',
                 'defaultEdgeWidth', 'defaultEdgeColor'])
-        edgeTab = QWidget()
-        edgeTab.setLayout(self._edge.getLayout())
-        self._autosave = SettingsCreator(['autosaveEnabled', 'autosaveInterval'])
-        autosaveTab = QWidget()
-        autosaveTab.setLayout(self._autosave.getLayout())
-        shortcutsTab = QWidget()
-        self._shortcuts = SettingsCreator(['shortcuts'])
-        shortcutsTab.setLayout(self._shortcuts.getLayout())
-        shortcutsScrollArea = QScrollArea()
-        shortcutsScrollArea.setWidgetResizable(True)
-        shortcutsScrollArea.setWidget(shortcutsTab)
-        tabWidget = QTabWidget()
-        tabWidget.addTab(generalTab, self.tr('General'))
-        tabWidget.addTab(nodeTab, self.tr('Node'))
-        tabWidget.addTab(edgeTab, self.tr('Edge && label'))
-        tabWidget.addTab(autosaveTab, self.tr('Autosave'))
-        tabWidget.addTab(shortcutsScrollArea, self.tr('Shortcuts'))
-        tabWidget.setUsesScrollButtons(False)
-        mainLayout = QVBoxLayout()
-        mainLayout.addWidget(tabWidget)
-        mainLayout.addWidget(self._buttonBox)
-        self.setLayout(mainLayout)
-
-    def _accept(self):
-        '''
-        Retrieve new settings
-        '''
-        self._newSettings.append(self._general.retrieve())
-        self._newSettings.append(self._node.retrieve())
-        self._newSettings.append(self._edge.retrieve())
-        self._newSettings.append(self._autosave.retrieve())
-        self._newSettings.append(self._shortcuts.retrieve())
-        SettingsDialog._accept(self)
+        self._createTab(self.tr('Autosave'), ['autosaveEnabled', 'autosaveInterval'])
+        self._createTab(self.tr('Shortcuts'), ['shortcuts'], True)
 
 
 class DesktopAffiliationDialog(AffiliationDialog):
@@ -453,9 +374,9 @@ class DesktopFindToolBar(FindToolBar):
         self.__nextButton.setIcon(QIcon.fromTheme('go-next'))
         self.__prevButton.setShortcut(QKeySequence.FindPrevious)
         self.__nextButton.setShortcut(QKeySequence.FindNext)
-        QObject.connect(self.__nextButton, SIGNAL('clicked()'), self._finder.nextFoundNode)
-        QObject.connect(self.__prevButton, SIGNAL('clicked()'), self._finder.prevFoundNode)
-        QObject.connect(self.__closeButton, SIGNAL('clicked()'), self.close)
+        self.__nextButton.clicked.connect(self._finder.nextFoundNode)
+        self.__prevButton.clicked.connect(self._finder.prevFoundNode)
+        self.__closeButton.clicked.connect(self.close)
 
     def _initComponents(self):
         '''
